==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Obraz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Utwórz płaszczyznę obrazu...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Utwórz płaski obraz w przestrzeni 3D</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>Utwórz płaski obraz w przestrzeni 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Obraz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Otwórz...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Otwórz widok obrazu</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Niezdefiniowana przestrzeń kolorów do podglądu obrazu</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Format piksela obrazu</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Wybierz orientację</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Płaszczyzna obrazu</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>Płaszczyzna X-Y</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>Płaszczyzna XZ</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>Płaszczyzna YZ</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Odwróć kierunek</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Odsunięcie:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Dopasuj obraz</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Rozciąga obraz, aby dopasować do widoku</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp; skala 1: 1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Wyświetlanie obrazu w skali 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp; Kolor oryginalny</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Wyświetlanie obrazu w oryginalnym kolorze (ach)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Rozjaśniony kolor</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Wyświetlaj obraz w rozjaśnionym kolorze(rach)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Gotowe ...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>szary</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>Powiększenie</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>poza obrazem</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Przeglądarka obrazów</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Format (*. png *. xpm *. jpg *. bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Wybierz plik obrazu, aby otworzyć</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Obrazy</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Wszystkie pliki</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Błąd podczas otwierania obrazu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Nie można załadować wybranego obrazu</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Błąd otwarcia obrazu</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nie można załadować wybranego obrazu</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Obraz</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Obraz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Utwórz płaszczyznę obrazu...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Utwórz płaski obraz w przestrzeni 3D</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>Utwórz płaski obraz w przestrzeni 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Obraz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Otwórz...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Otwórz widok obrazu</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Obraz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Skaluj...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Skalowanie obrazu</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Niezdefiniowana przestrzeń kolorów do podglądu obrazu</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Format piksela obrazu</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Wybierz orientację</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Płaszczyzna obrazu</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>Płaszczyzna X-Y</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>Płaszczyzna XZ</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>Płaszczyzna YZ</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Odwróć kierunek</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Odsunięcie:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Dopasuj obraz</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Rozciąga obraz, aby dopasować do widoku</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp; skala 1: 1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Wyświetlanie obrazu w skali 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp; Kolor oryginalny</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Wyświetlanie obrazu w oryginalnym kolorze (ach)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Rozjaśniony kolor</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Wyświetlaj obraz w rozjaśnionym kolorze(rach)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Gotowe ...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>szary</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>Powiększenie</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>poza obrazem</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Przeglądarka obrazów</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Format (*. png *. xpm *. jpg *. bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Wybierz plik obrazu, aby otworzyć</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Obrazy</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Wszystkie pliki</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Błąd podczas otwierania obrazu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Nie można załadować wybranego obrazu</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Błąd otwarcia obrazu</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nie można załadować wybranego obrazu</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Obraz</translation>
    </message>
  </context>
</TS>
